{% extends "aa_contacts/base.html" %}
{% load django_bootstrap5 %}
{% load i18n %}

{% block aacontactscontent %}
    <div class="col-12">
        <div class="card">
            <div class="card-body">
                <h5 class="card-title text-center"><img src="{{ contact.image_src }}" class="rounded me-2">{{ contact.contact_name }}</h5>
                <form method="post"> {% csrf_token %}
                    {% bootstrap_form form %}
                    <button type="submit" class="btn btn-primary">{% translate "Submit" %}</button>
                </form>
            </div>
        </div>
    </div>
{% endblock aacontactscontent %}