{% extends 'allianceauth/base-bs5.html' %}

{% load i18n %}

{% block page_title %}
    {% translate "Contacts" %}
{% endblock %}

{% block header_nav_brand %}
    {% translate "Contacts" %}
{% endblock header_nav_brand %}

{% block header_nav_collapse_left %}
    {% include "aa_contacts/switch_frontend_version.html" %}
{% endblock header_nav_collapse_left %}

{% block content %}
    <div class="row">
        {% block aacontactscontent %}{% endblock aacontactscontent %}
    </div>
{% endblock content %}
