{% load i18n %}

<li class="nav-item">
    {% if request.path|slice:":11" == "/contacts/r" %}
        <a class="nav-link" href="{% url "aa_contacts:dashboard" %}">{% translate "Legacy UI" %}</a>
    {% else %}
        <a class="nav-link" href="{% url "aa_contacts:react_view" %}">{% translate "New UI" %}</a>
    {% endif %}
</li>

